.. cb_key_stroke documentation master file, created by
   sphinx-quickstart on Tue Oct 18 10:01:03 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Chriesibaum's Key Stroke Module Documentation!
=========================================================

**cb_key_stroke** is a small module to quit/terminate a loop of a console app
by simply pressing a key. The beauty is that this module is running on Linux,
Öpfel-Rechnern as well Fenster operated computers.

Sample Code
-----------
A very basic example to demonstrate the usage of the cb_key_stroke module:

.. literalinclude:: ../../examples/cb_key_stroke_basic_usage.py
   :lines: 3-

You can find more examples in the following folder:
./examples


I will be happy to help you across the road if you have any questions or clarifications. |br|
Enjoy the **cb_key_stroke** module! |br|
Thomas@chriesibaum.dev


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation

   modules

   readme

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`




.. |br| raw:: html

      <br>
